@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1700';
+our $VERSION = '0.1701';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -84,6 +84,18 @@ sub parse {
     }
     print "NOTES: @notes\n" if $self->verbose;
 
+# XXX Not working?
+#    my %ss_enharmonics = (
+#        'C##' => 'D',
+#        'D##' => 'E',
+#        'F##' => 'G',
+#        'G##' => 'A',
+#    );
+#    for ( @notes ) {
+#        s/$_/$ss_enharmonics{$_}/
+#            if $ss_enharmonics{$_};
+#    }
+
     # Convert a diminished chord
     $chord =~ s/dim/o/;
 
@@ -106,7 +118,23 @@ sub parse {
     # Get the roman representation based on the scale position
     my $position = first_index { $_ eq $note } @notes;
 
+    if ( $position < 0 && ( $note eq 'Cb' || $note eq 'Fb' ) ) {
+        $note = 'B'
+            if $note eq 'Cb';
+        $note = 'E'
+            if $note eq 'Fb';
+        $position = first_index { $_ eq $note } @notes;
+    }
+    elsif ( $note eq 'E#' ) {
+        $note = 'F';
+    }
+
     my $accidental = '';
+    # If the note is not in the scale find the new position and accidental
+    if ( $position < 0 ) {
+        ( $position, $accidental ) = _pos_acc( $note, $position, \@notes );
+    }
+
     if ( $position < 0 && $note =~ /[#b]+$/ ) {
         my $n = Music::Note->new( $note, 'isobase' );
         my $name = $n->format('isobase');
@@ -117,12 +145,6 @@ sub parse {
         $accidental = '';
     }
 
-    # If the note is not in the scale find the new position and accidental
-    if ( $position < 0 ) {
-        ( $position, $accidental ) = _pos_acc( $note, $position, \@notes );
-    }
-    $accidental ||= '';
-
     my $roman = $scale[$position];
     print "ROMAN 1: $roman\n" if $self->verbose;
 
@@ -316,7 +338,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1700
+version 0.1701
 
 =head1 SYNOPSIS
 
